@@ -26,19 +26,26 @@
 
 ;;; Code:
 
+(eval-when-compile
+  (require 'cl))
+
 (require 'shimbun)
 (require 'sb-text)
 
 (luna-define-class shimbun-tdiary (shimbun shimbun-text) ())
 
-(defvar shimbun-tdiary-content-start "</h3>")
+(defvar shimbun-tdiary-content-start "<h3")
 (defvar shimbun-tdiary-content-end "</div>")
 
-(defvar shimbun-tdiary-group-alist nil
-  "An alist of TDIARY shimbun group definition.
+(defcustom shimbun-tdiary-group-alist nil
+  "*An alist of TDIARY shimbun group definition.
 Each element looks like (NAME URL).
 NAME is a shimbun group name.
-URL is the URL for TDIARY access point of the group.")
+URL is the URL for TDIARY access point of the group."
+  :group 'shimbun
+  :type '(repeat (cons :format "%v"
+		       (string :tag "Group name")
+		       (string :tag "URL"))))
 
 (luna-define-method shimbun-groups ((shimbun shimbun-tdiary))
   (mapcar 'car shimbun-tdiary-group-alist))
@@ -47,56 +54,27 @@ URL is the URL for TDIARY access point of the group.")
   (cadr (assoc (shimbun-current-group-internal shimbun)
 	       shimbun-tdiary-group-alist)))
 
-;; FIXME: since this is a convenient function, it should be rearranged
-;; to be shared by all the shimbun modules.  The definition is imported
-;; from Gnus.
-(eval-when-compile
-  (if (not (fboundp 'replace-regexp-in-string))
-      ;; Silence the byte-compiler.
-      (defalias 'replace-regexp-in-string 'ignore)))
-
-(eval-and-compile
-  (cond
-   ((fboundp 'replace-in-string)
-    (defalias 'shimbun-replace-in-string 'replace-in-string))
-   ((fboundp 'replace-regexp-in-string)
-    (defun shimbun-replace-in-string  (string regexp newtext &optional literal)
-      (replace-regexp-in-string regexp newtext string nil literal)))
-   (t
-    (defun shimbun-replace-in-string (string regexp newtext &optional literal)
-      (let ((start 0) tail)
-	(while (string-match regexp string start)
-	  (setq tail (- (length string) (match-end 0)))
-	  (setq string (replace-match newtext nil literal string))
-	  (setq start (- (length string) tail))))
-      string))))
-
 (defmacro shimbun-tdiary-get-headers (shimbun url headers &optional aux)
   (` (let ((case-fold-search t))
        (goto-char (point-max))
-       (while (re-search-backward "<h3[^>]*><a href=\"\./\\(.*\\([0-9][0-9][0-9][0-9]\\)\\([0-9][0-9]\\)\\([0-9][0-9]\\).*#\\(p[0-9]+\\)\\)\"><span class=\"[ps]anchor\">.+</span></a>\\(.+]\\|\\) \\(.+\\)</h3>" nil t)
+       (while (re-search-backward "<h3[^>]*><a href=\"\./\\(.*\\([0-9][0-9][0-9][0-9]\\)\\([0-9][0-9]\\)\\([0-9][0-9]\\).*#\\(p[0-9]+\\)\\)\"> *\\(<span class=\"[ps]anchor\">.+</span>\\)?[^<]*</a>\\(.+]\\|\\) *\\(.+\\)</h3>" nil t)
 	 (let ((url (match-string 1))
 	       (year (match-string 2))
 	       (month (match-string 3))
 	       (day (match-string 4))
 	       (topic (match-string 5))
-	       (subject (match-string 7))
+	       (subject (match-string 8))
 	       date id)
-	   (setq subject (shimbun-replace-in-string subject "<[^>]+>" ""))
 	   (setq date (shimbun-make-date-string (string-to-number year)
 						(string-to-number month)
 						(string-to-number day)))
 	   (setq id (format "<%s.%s%s%s.%s@tdiary.org>"
 			    topic year month day
-			    (shimbun-current-group-internal (, shimbun))))
-	   (push (shimbun-make-header
-		  0
-		  (shimbun-mime-encode-string subject)
-		  (or (shimbun-mime-encode-string (, aux))
-		      (shimbun-from-address (, shimbun)))
-		  date id "" 0 0 (concat
-				  (shimbun-index-url (, shimbun))
-				  url))
+			    (eword-encode-string
+			     (shimbun-current-group-internal (, shimbun)))))
+	   (push (shimbun-create-header
+		  0 subject (or (, aux) (shimbun-from-address (, shimbun)))
+		  date id "" 0 0 (concat (shimbun-index-url (, shimbun)) url))
 		 (, headers))))
        (, headers))))
 
@@ -139,28 +117,51 @@ URL is the URL for TDIARY access point of the group.")
 		(setq month (shimbun-tdiary-make-date count first))
 		(push month months)))
     (setq months (nreverse months))
-    (erase-buffer)
     (dolist (month months)
       (let ((url (concat (shimbun-index-url shimbun) "?date=" month)))
+	(erase-buffer)
 	(shimbun-retrieve-url url t)
+	(goto-char (point-min))
+	(while (search-forward "\r" nil t)
+	  (delete-char -1))
 	(shimbun-tdiary-get-headers shimbun url headers author)))
     headers))
 
+(defvar shimbun-tdiary-footnote-regex
+  (concat "<span class=\"footnote\">"
+	  "<a +name=\"\\([^\"]*\\)\" +"
+	  "href=\"\\([^#]*\\)#[^\"]+\" +"
+	  "title=\"\\([^\"]*\\)\">"
+	  "\\(\\*[0-9]+\\)</a></span>")
+  "Regexp of footnote.")
+
 (luna-define-method shimbun-make-contents ((shimbun shimbun-tdiary)
 					   header)
   (let ((case-fold-search t)
 	(id (shimbun-header-id header))
-	(start))
+	start footnotes)
     (when (string-match "\\(p[0-9]+\\)\." id)
       (setq id (substring id (match-beginning 1) (match-end 1)))
-      (re-search-forward (concat "<a name=\"" id) nil t))
+      (re-search-forward (concat "<a name=\"" id) nil t)
+      (and (search-backward shimbun-tdiary-content-start nil t)
+	   (goto-char (match-beginning 0))))
     (when (and (re-search-forward (shimbun-content-start-internal shimbun)
 				  nil t)
-	       (setq start (point))
+	       (setq start (match-beginning 0))
 	       (re-search-forward (shimbun-content-end-internal shimbun)
 				  nil t))
       (delete-region (match-beginning 0) (point-max))
       (delete-region (point-min) start))
+    (goto-char (point-min))
+    (while (re-search-forward shimbun-tdiary-footnote-regex nil t)
+      (setq footnotes (cons (format "<a href=\"%s#%s\">%s</a> %s<br>\n"
+				    (match-string 2) (match-string 1)
+				    (match-string 4) (match-string 3))
+			    footnotes)))
+    (when footnotes
+      (goto-char (point-max))
+      (insert "<br><br>\n")
+      (mapcar 'insert (nreverse footnotes)))
     (shimbun-header-insert-and-buffer-string shimbun header nil t)))
 
 (provide 'sb-tdiary)
